summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLeela Venkata Kiran Kumar Reddy Chirala <kchirala@qca.qualcomm.com>2014-07-10 18:40:50 -0700
committerAkash Patel <c_akashp@qca.qualcomm.com>2014-07-14 17:43:41 -0700
commit8b6e36f4c137b096aea8bc1504fb0e7023ee81ff (patch)
tree3fe999542f3d3207b3ce0b792ce79c982f7ed952
parent5cc72285d00de4c32071c2aab405943786622d9d (diff)
WLAN:CORESTACK: make the structure common for psk and pmk
For passing on the psk or pmk to the firmware use the same array Change-Id: Ic96dcf96bca83e825cdf6ed0e48f96a5222b7fc3 CRs-fixed: 692028
-rw-r--r--CORE/HDD/src/wlan_hdd_cfg80211.c2
-rw-r--r--CORE/MAC/inc/sirApi.h2
-rw-r--r--CORE/SME/inc/csrInternal.h2
-rw-r--r--CORE/SME/inc/sme_Api.h10
-rw-r--r--CORE/SME/src/csr/csrApiRoam.c8
-rw-r--r--CORE/SME/src/csr/csrInsideApi.h8
-rw-r--r--CORE/SME/src/sme_common/sme_Api.c12
7 files changed, 22 insertions, 22 deletions
diff --git a/CORE/HDD/src/wlan_hdd_cfg80211.c b/CORE/HDD/src/wlan_hdd_cfg80211.c
index 82ee6358ec21..210474781077 100644
--- a/CORE/HDD/src/wlan_hdd_cfg80211.c
+++ b/CORE/HDD/src/wlan_hdd_cfg80211.c
@@ -9783,7 +9783,7 @@ static int __wlan_hdd_cfg80211_connect( struct wiphy *wiphy,
) {
hddLog(VOS_TRACE_LEVEL_ERROR, FL("calling sme_RoamSetPSK"));
vos_mem_copy(localPsk, req->psk, SIR_ROAM_SCAN_PSK_SIZE);
- sme_RoamSetPSK(WLAN_HDD_GET_HAL_CTX(pAdapter),
+ sme_RoamSetPSK_PMK(WLAN_HDD_GET_HAL_CTX(pAdapter),
pAdapter->sessionId, localPsk);
}
}
diff --git a/CORE/MAC/inc/sirApi.h b/CORE/MAC/inc/sirApi.h
index 7243b28c7a39..c468c899c139 100644
--- a/CORE/MAC/inc/sirApi.h
+++ b/CORE/MAC/inc/sirApi.h
@@ -4003,7 +4003,7 @@ typedef struct sSirRoamOffloadScanReq
eSirDFSRoamScanMode allowDFSChannelRoam;
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
tANI_U8 RoamOffloadEnabled;
- tANI_U8 PSK[SIR_ROAM_SCAN_PSK_SIZE];
+ tANI_U8 PSK_PMK[SIR_ROAM_SCAN_PSK_SIZE];
tANI_U8 Prefer5GHz;
tANI_U8 RoamRssiCatGap;
tANI_U8 Select5GHzMargin;
diff --git a/CORE/SME/inc/csrInternal.h b/CORE/SME/inc/csrInternal.h
index ba0085860d60..f135503df259 100644
--- a/CORE/SME/inc/csrInternal.h
+++ b/CORE/SME/inc/csrInternal.h
@@ -1019,7 +1019,7 @@ typedef struct tagCsrRoamSession
#endif
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
tCsrRoamOffloadSynchStruct roamOffloadSynchParams;
- tANI_U8 psk[SIR_ROAM_SCAN_PSK_SIZE];
+ tANI_U8 psk_pmk[SIR_ROAM_SCAN_PSK_SIZE];
#endif
} tCsrRoamSession;
diff --git a/CORE/SME/src/csr/csrApiRoam.c b/CORE/SME/src/csr/csrApiRoam.c
index 0282204940d2..eba31df65e76 100644
--- a/CORE/SME/src/csr/csrApiRoam.c
+++ b/CORE/SME/src/csr/csrApiRoam.c
@@ -12409,15 +12409,15 @@ tANI_U32 csrRoamGetNumBKIDCache(tpAniSirGlobal pMac, tANI_U32 sessionId)
}
#endif /* FEATURE_WLAN_WAPI */
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
-eHalStatus csrRoamSetPSK (tpAniSirGlobal pMac, tANI_U32 sessionId,
- tANI_U8 *pPSK)
+eHalStatus csrRoamSetPSK_PMK (tpAniSirGlobal pMac, tANI_U32 sessionId,
+ tANI_U8 *pPSK_PMK)
{
tCsrRoamSession *pSession = CSR_GET_SESSION(pMac, sessionId);
if (!pSession) {
smsLog(pMac, LOGE, FL("session %d not found"), sessionId);
return eHAL_STATUS_FAILURE;
}
- vos_mem_copy(pSession->psk, pPSK, sizeof(pSession->psk));
+ vos_mem_copy(pSession->psk_pmk, pPSK_PMK, sizeof(pSession->psk_pmk));
return eHAL_STATUS_SUCCESS;
}
#endif /* WLAN_FEATURE_ROAM_OFFLOAD */
@@ -16377,7 +16377,7 @@ csrRoamScanOffloadPrepareProbeReqTemplate(tpAniSirGlobal pMac,
void csrRoamOffload(tpAniSirGlobal pMac, tSirRoamOffloadScanReq *pRequestBuf,
tCsrRoamSession *pSession)
{
- vos_mem_copy(pRequestBuf->PSK, pSession->psk, sizeof(pRequestBuf->PSK));
+ vos_mem_copy(pRequestBuf->PSK_PMK, pSession->psk_pmk, sizeof(pRequestBuf->PSK_PMK));
pRequestBuf->Prefer5GHz = pMac->roam.configParam.nRoamPrefer5GHz;
pRequestBuf->RoamRssiCatGap = pMac->roam.configParam.bCatRssiOffset;
pRequestBuf->Select5GHzMargin = pMac->roam.configParam.nSelect5GHzMargin;
diff --git a/CORE/SME/inc/sme_Api.h b/CORE/SME/inc/sme_Api.h
index 03e57b612ed1..f2320897dd62 100644
--- a/CORE/SME/inc/sme_Api.h
+++ b/CORE/SME/inc/sme_Api.h
@@ -842,15 +842,15 @@ eHalStatus sme_RoamSetPMKIDCache( tHalHandle hHal, tANI_U8 sessionId, tPmkidCach
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
/* ---------------------------------------------------------------------------
* \fn sme_RoamSetPSK
* \brief a wrapper function to request CSR to save PSK
* This is a synchronous call.
* \param hHal - Global structure
* \param sessionId - SME sessionId
* \param pPSK - pointer to an array of Psk[]
*\return eHalStatus -status whether PSK is set or not
* ---------------------------------------------------------------------------*/
-eHalStatus sme_RoamSetPSK ( tHalHandle hHal, tANI_U8 sessionId, tANI_U8 *pPSK );
+eHalStatus sme_RoamSetPSK_PMK ( tHalHandle hHal, tANI_U8 sessionId, tANI_U8 *pPSK_PMK );
#endif
/* ---------------------------------------------------------------------------
\fn sme_RoamGetSecurityReqIE
@@ -842,15 +842,15 @@ eHalStatus sme_RoamSetPMKIDCache( tHalHandle hHal, tANI_U8 sessionId, tPmkidCach
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
/* ---------------------------------------------------------------------------
- * \fn sme_RoamSetPSK
- * \brief a wrapper function to request CSR to save PSK
+ * \fn sme_RoamSetPSK_PMK
+ * \brief a wrapper function to request CSR to save PSK/PMK
* This is a synchronous call.
* \param hHal - Global structure
@@ -842,15 +842,15 @@ eHalStatus sme_RoamSetPMKIDCache( tHalHandle hHal, tANI_U8 sessionId, tPmkidCach
* \param hHal - Global structure
* \param sessionId - SME sessionId
- * \param pPSK - pointer to an array of Psk[]
- *\return eHalStatus -status whether PSK is set or not
+ * \param pPSK_PMK - pointer to an array of Psk[]/Pmk[]
+ *\return eHalStatus -status whether PSK/PMK is set or not
* ---------------------------------------------------------------------------*/
diff --git a/CORE/SME/src/csr/csrInsideApi.h b/CORE/SME/src/csr/csrInsideApi.h
index 34b9f1804fbb..46be5f9c1193 100644
--- a/CORE/SME/src/csr/csrInsideApi.h
+++ b/CORE/SME/src/csr/csrInsideApi.h
@@ -758,15 +758,15 @@ eHalStatus csrRoamSetPMKIDCache( tpAniSirGlobal pMac, tANI_U32 sessionId, tPmkid
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
/* ---------------------------------------------------------------------------
- *\fn csrRoamSetPSK
- *\brief store PSK
+ *\fn csrRoamSetPSK_PMK
+ *\brief store PSK/PMK
*\param pMac - pointer to global structure for MAC
*\param sessionId - Sme session id
*\param pPSK - pointer to an array of Psk
*\return eHalStatus - usually it succeed unless sessionId is not found
*\Note:
*-------------------------------------------------------------------------------*/
-eHalStatus csrRoamSetPSK (tpAniSirGlobal pMac, tANI_U32 sessionId, tANI_U8 *pPSK);
+eHalStatus csrRoamSetPSK_PMK (tpAniSirGlobal pMac, tANI_U32 sessionId, tANI_U8 *pPSK_PMK);
#endif
/* ---------------------------------------------------------------------------
\fn csrRoamGetWpaRsnReqIE
@@ -758,15 +758,15 @@ eHalStatus csrRoamSetPMKIDCache( tpAniSirGlobal pMac, tANI_U32 sessionId, tPmkid
*\param pMac - pointer to global structure for MAC
*\param sessionId - Sme session id
- *\param pPSK - pointer to an array of Psk
+ *\param pPSK_PMK - pointer to an array of Psk/Pmk
*\return eHalStatus - usually it succeed unless sessionId is not found
*\Note:
diff --git a/CORE/SME/src/sme_common/sme_Api.c b/CORE/SME/src/sme_common/sme_Api.c
index 9e5718593b89..24e00930bdee 100644
--- a/CORE/SME/src/sme_common/sme_Api.c
+++ b/CORE/SME/src/sme_common/sme_Api.c
@@ -3935,22 +3935,22 @@ eHalStatus sme_RoamDelPMKIDfromCache( tHalHandle hHal, tANI_U8 sessionId, tANI_U
}
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
/* ---------------------------------------------------------------------------
*\fn sme_RoamSetPSK
*\brief a wrapper function to request CSR to save PSK
* This is a synchronous call.
*\param hHal - Global structure
*\param sessionId - SME sessionId
*\param pPSK - pointer to an array of Psk[]
*\return eHalStatus -status whether PSK is set or not
*---------------------------------------------------------------------------*/
-eHalStatus sme_RoamSetPSK (tHalHandle hHal, tANI_U8 sessionId, tANI_U8 *pPSK)
+eHalStatus sme_RoamSetPSK_PMK (tHalHandle hHal, tANI_U8 sessionId, tANI_U8 *pPSK_PMK)
{
eHalStatus status = eHAL_STATUS_FAILURE;
tpAniSirGlobal pMac = PMAC_STRUCT(hHal);
status = sme_AcquireGlobalLock(&pMac->sme);
if (HAL_STATUS_SUCCESS(status)) {
if (CSR_IS_SESSION_VALID(pMac, sessionId)) {
- status = csrRoamSetPSK(pMac, sessionId, pPSK);
+ status = csrRoamSetPSK_PMK(pMac, sessionId, pPSK_PMK);
}
else {
status = eHAL_STATUS_INVALID_PARAMETER;
@@ -3935,22 +3935,22 @@ eHalStatus sme_RoamDelPMKIDfromCache( tHalHandle hHal, tANI_U8 sessionId, tANI_U
#ifdef WLAN_FEATURE_ROAM_OFFLOAD
/* ---------------------------------------------------------------------------
- *\fn sme_RoamSetPSK
- *\brief a wrapper function to request CSR to save PSK
+ *\fn sme_RoamSetPSK_PMK
+ *\brief a wrapper function to request CSR to save PSK/PMK
* This is a synchronous call.
*\param hHal - Global structure
@@ -3935,22 +3935,22 @@ eHalStatus sme_RoamDelPMKIDfromCache( tHalHandle hHal, tANI_U8 sessionId, tANI_U
*\param hHal - Global structure
*\param sessionId - SME sessionId
- *\param pPSK - pointer to an array of Psk[]
- *\return eHalStatus -status whether PSK is set or not
+ *\param pPSK_PMK - pointer to an array of Psk[]/Pmk
+ *\return eHalStatus -status whether PSK/PMK is set or not
*---------------------------------------------------------------------------*/